@@ -2,6 +2,7 @@
 #include <string>
 #include <algorithm>
 #include <cmath>
+#include <R_ext/Arith.h>
 
 using namespace std;
 
@@ -17,12 +18,13 @@ unsigned char UNSIGNED_CHAR_NAN;
 char const* parseFormats[9];
 
 int initConsts(){
+  int i;
   sscanf("32767","%hi",&SHORT_INT_NAN);
   sscanf("65535","%hu",&UNSIGNED_SHORT_INT_NAN);
   sscanf("2147483647","%i",&INT_NAN);
   sscanf("4294967295","%u",&UNSIGNED_INT_NAN);
-  sscanf("127","%i",&CHAR_NAN);
-  sscanf("255","%u",&UNSIGNED_CHAR_NAN);
+  sscanf("127","%i",&i); CHAR_NAN = i;
+  sscanf("255","%u",&i); UNSIGNED_CHAR_NAN = i;
 
   parseFormats[UNSIGNED_SHORT_INT] = "%hu";
   parseFormats[SHORT_INT] = "%hd";
@@ -32,6 +34,7 @@ int initConsts(){
   parseFormats[DOUBLE] = "%lf";
   parseFormats[SIGNED_CHAR] = "%i";
   parseFormats[UNSIGNED_CHAR] = "%i";
+  return 0;
 }
 
 int dummy = initConsts();
@@ -86,7 +89,7 @@ string dataTypeToString(int type){
 }
 
 string bufToString(short int dataType, char *data, string nanString){
-	char ret[20];
+	char ret[500];
 	switch(dataType){
 	case UNSIGNED_SHORT_INT:
 		sprintf(ret, "%hu", *(unsigned short int*)data);
@@ -181,16 +184,17 @@ bool checkNan(void *data, int dataType){
     	    return (*(unsigned int*) data) == UNSIGNED_INT_NAN;
     	case INT:
     	    return (*(int*) data) == INT_NAN;
-    	case FLOAT:
-    	    return isnan(*(float*) data);
+//    	case FLOAT:
+//    	    return ::isnan(*(float*) data);
     	case DOUBLE:
-    	    return isnan(*(double*) data);
+    	    return ISNAN(*(double*) data);
     	case UNSIGNED_CHAR:
     	    return (*(unsigned char*) data) == UNSIGNED_CHAR_NAN;
     	case SIGNED_CHAR:
     	    return (*(char*) data) == CHAR_NAN;
     	default:
     		errorLog << "file contains data of unknown type " << dataType << endl << errorExit;
+    		return false;
    }
 }
 
